class Boolean(object):
    def __init__(self, storage):
        self.storage = storage

    def get(self, raw: []) -> bool:
        return [True if raw[0] == 'true' else False]

    def put(self, val: bool) -> []:
        return ['true' if val else 'false']
